@@ -33,45 +33,49 @@
  */
 
 static const NVGetoptOption __options[] = {
-    { "version", 'v', 0, NULL,
-      "Print the <nvidia-settings> version and exit." },
+    { "version", 'v', NVGETOPT_HELP_ALWAYS, NULL,
+      "Print the ^nvidia-settings^ version and exit." },
 
-    { "help", 'h', 0, NULL,
+    { "help", 'h', NVGETOPT_HELP_ALWAYS, NULL,
       "Print usage information and exit." },
 
-    { "config", CONFIG_FILE_OPTION, NVGETOPT_STRING_ARGUMENT, NULL,
-      "Use the configuration file ^CONFIG> rather than the "
-      "default ^" DEFAULT_RC_FILE ">" },
+    { "config", CONFIG_FILE_OPTION,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_HELP_ALWAYS, NULL,
+      "Use the configuration file &CONFIG& rather than the "
+      "default &" DEFAULT_RC_FILE "&" },
 
-    { "ctrl-display", 'c', NVGETOPT_STRING_ARGUMENT, NULL,
+    { "ctrl-display", 'c',
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_HELP_ALWAYS, NULL,
       "Control the specified X display.  If this option is not given, then "
-      "<nvidia-settings> will control the display specified by <'--display'>; "
-      "if that is not given, then the ^$DISPLAY> environment variable is used." },
+      "^nvidia-settings^ will control the display specified by ^'--display'^; "
+      "if that is not given, then the &$DISPLAY& environment "
+      "variable is used." },
 
-    { "load-config-only", 'l', 0, NULL,
+    { "load-config-only", 'l', NVGETOPT_HELP_ALWAYS, NULL,
       "Load the configuration file, send the values specified therein to "
       "the X server, and exit.  This mode of operation is useful to place "
       "in your xinitrc file, for example." },
 
-    { "no-config", 'n', 0, NULL,
+    { "no-config", 'n', NVGETOPT_HELP_ALWAYS, NULL,
       "Do not load the configuration file.  This mode of operation is useful "
-      "if <nvidia-settings> has difficulties starting due to problems with "
+      "if ^nvidia-settings^ has difficulties starting due to problems with "
       "applying settings in the configuration file." },
 
-    { "rewrite-config-file", 'r', 0, NULL,
+    { "rewrite-config-file", 'r', NVGETOPT_HELP_ALWAYS, NULL,
       "Write the X server configuration to the configuration file, and exit, "
       "without starting the graphical user interface.  See EXAMPLES section." },
 
     { "verbose", 'V',
-      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ARGUMENT_IS_OPTIONAL, NULL,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ARGUMENT_IS_OPTIONAL |
+      NVGETOPT_HELP_ALWAYS, NULL,
       "Controls how much information is printed.  By default, the verbosity "
-      "is <errors> and only error messages are printed.  Valid values are "
-      "<'none'> (do not print messages), <'errors'> (print error messages), "
-      "<'warnings'> (print error and warning messages), and "
-      "<'all'> (print error, warning and other informational messages)." },
+      "is ^errors^ and only error messages are printed.  Valid values are "
+      "^'none'^ (do not print messages), ^'errors'^ (print error messages), "
+      "^'warnings'^ (print error and warning messages), and "
+      "^'all'^ (print error, warning and other informational messages)." },
 
-    { "assign", 'a', NVGETOPT_STRING_ARGUMENT, NULL,
-      "The ^ASSIGN> argument to the <'--assign'> command line option is of the "
+    { "assign", 'a', NVGETOPT_STRING_ARGUMENT | NVGETOPT_HELP_ALWAYS, NULL,
+      "The &ASSIGN& argument to the ^'--assign'^ command line option is of the "
       "form:\n"
       "\n"
       TAB "{DISPLAY}/{attribute name}[{display devices}]={value}\n"
@@ -80,7 +84,7 @@ static const NVGetoptOption __options[] = {
       "X Display {DISPLAY}.  {DISPLAY} follows the usual {host}:{display}."
       "{screen} syntax of the DISPLAY environment variable and is optional; "
       "when it is not specified, then it is implied following the same rule as "
-      "the <--ctrl-display> option.  If the X screen is not specified, then the "
+      "the ^--ctrl-display^ option.  If the X screen is not specified, then the "
       "assignment is made to all X screens.  Note that the '/' is only required "
       "when {DISPLAY} is present.\n"
       "\n"
@@ -88,8 +92,8 @@ static const NVGetoptOption __options[] = {
       "an assignment to something other than an X screen.  A target "
       "specification is contained within brackets and consists of a target "
       "type name, a colon, and the target id.  The target type name can be "
-      "one of <\"screen\", \"gpu\", \"framelock\", \"vcs\", \"gvi\",> or "
-      "<\"fan\";> the target id is the index into the list of targets "
+      "one of ^\"screen\", \"gpu\", \"framelock\", \"vcs\", \"gvi\",^ or "
+      "^\"fan\";^ the target id is the index into the list of targets "
       "(for that target type).  The target specification can be used in "
       "{DISPLAY} wherever an X screen can be used, following the syntax "
       "{host}:{display}[{target_type}:{target_id}].  See the output of\n"
@@ -114,41 +118,41 @@ static const NVGetoptOption __options[] = {
       TAB "--assign=\"SyncToVBlank=1\"\n"
       TAB "-a [gpu:0]/DigitalVibrance[DFP-1]=63\n" },
 
-    { "query", 'q', NVGETOPT_STRING_ARGUMENT, NULL,
-      "The ^QUERY> argument to the <'--query'> command line option is of the "
+    { "query", 'q', NVGETOPT_STRING_ARGUMENT | NVGETOPT_HELP_ALWAYS, NULL,
+      "The &QUERY& argument to the ^'--query'^ command line option is of the "
       "form:\n"
       "\n"
       TAB "{DISPLAY}/{attribute name}[{display devices}]\n"
       "\n"
       "This queries the current value of the attribute {attribute name} on the "
       "X Display {DISPLAY}.  The syntax is the same as that for the "
-      "<'--assign'> option, without '=<{value}'>; specify <'-q screens', "
-      "'-q gpus', '-q framelocks', '-q vcs', '-q gvis', or '-q fans'> to "
+      "^'--assign'^ option, without '=^{value}'^; specify ^'-q screens', "
+      "'-q gpus', '-q framelocks', '-q vcs', '-q gvis', or '-q fans'^ to "
       "query a list of X screens, GPUs, Frame Lock devices, Visual Computing "
       "Systems, SDI Input Devices, or Fans, respectively, that are present "
-      "on the X Display {DISPLAY}.  Specify <'-q all'> to query all attributes." },
+      "on the X Display {DISPLAY}.  Specify ^'-q all'^ to query all attributes." },
 
-    { "terse", 't', 0, NULL,
+    { "terse", 't', NVGETOPT_HELP_ALWAYS, NULL,
       "When querying attribute values with the '--query' command line option, "
       "only print the current value, rather than the more verbose description "
       "of the attribute, its valid values, and its current value." },
 
-    { "display-device-string", 'd', 0, NULL,
+    { "display-device-string", 'd', NVGETOPT_HELP_ALWAYS, NULL,
       "When printing attribute values in response to the '--query' option, "
       "if the attribute value is a display device mask, print the value "
       "as a list of display devices (e.g., \"CRT-0, DFP-0\"), rather than "
       "a hexadecimal bit mask (e.g., 0x00010001)." },
 
-    { "glxinfo", 'g', 0, NULL,
+    { "glxinfo", 'g', NVGETOPT_HELP_ALWAYS, NULL,
       "Print GLX Information for the X display and exit." },
 
-    { "describe", 'e', NVGETOPT_STRING_ARGUMENT, NULL,
+    { "describe", 'e', NVGETOPT_STRING_ARGUMENT | NVGETOPT_HELP_ALWAYS, NULL,
       "Prints information about a particular attribute.  Specify 'all' to "
       "list the descriptions of all attributes.  Specify 'list' to list the "
       "attribute names without a descriptions." },
 
-    { "page", 'p', NVGETOPT_STRING_ARGUMENT, NULL,
-      "The ^PAGE> argument to the <'--page'> commandline option selects a "
+    { "page", 'p', NVGETOPT_STRING_ARGUMENT | NVGETOPT_HELP_ALWAYS, NULL,
+      "The &PAGE& argument to the ^'--page'^ commandline option selects a "
       "particular page in the nvidia-settings user interface to display "
       "upon starting nvidia-settings.  Valid values are the page names "
       "in the tree view on the left side of the nvidia-settings user "
@@ -163,9 +167,19 @@ static const NVGetoptOption __options[] = {
       "\n"
       TAB "--page=\"GPU 0 - (Quadro 6000), PowerMizer\"\n"
       "\n"
-      "The first page with a name matching the ^PAGE> argument will be used.  "
+      "The first page with a name matching the &PAGE& argument will be used.  "
       "By default, the \"X Server Information\" page is displayed." },
 
+    { "list-targets-only", 'L', NVGETOPT_HELP_ALWAYS, NULL,
+      "When performing an attribute query (from the '--query' command line "
+      "option) or an attribute assignment (from the '--assign' command line "
+      "option or when loading an ~/.nvidia-settings-rc file), nvidia-settings "
+      "identifies one or more targets on which to query/assign the attribute.\n"
+      "\n"
+      "'--list-targets-only' will cause nvidia-settings to list the targets on "
+      " which the query/assign operation would have been performed, without "
+      "actually performing the operation(s), and exit." },
+
     { NULL, 0, 0, NULL, NULL},
 };
 
